@@ -225,12 +225,7 @@ impl CookieJar {
     /// ```
     pub fn remove(&mut self, mut cookie: Cookie<'static>) {
         let name = cookie.name();
-        if self
-            .original_cookies
-            .iter()
-            .position(|e| e.name() == name)
-            .is_some()
-        {
+        if self.original_cookies.iter().any(|e| e.name() == name) {
             cookie.make_removal();
             self.delta_cookies
                 .upsert_cookie(DeltaCookie::removed(cookie));
@@ -313,7 +308,7 @@ impl CookieJar {
     /// assert_eq!(jar.delta().count(), 0);
     /// ```
     pub fn reset_delta(&mut self) {
-        self.delta_cookies = vec![]
+        self.delta_cookies.clear();
     }
 
     /// Returns an iterator over cookies that represent the changes to this jar
