@@ -28,6 +28,7 @@ mod parse;
 
 use std::borrow::Cow;
 use std::fmt;
+use std::fmt::Write;
 use std::str::FromStr;
 
 #[allow(unused_imports, deprecated)]
@@ -222,7 +223,7 @@ impl<'c> Cookie<'c> {
     where
         S: Into<Cow<'c, str>>,
     {
-        parse_cookie(s, false)
+        parse_cookie(s)
     }
 
     /// Converts `self` into a `Cookie` with a static lifetime with as few
@@ -715,31 +716,35 @@ impl<'c> Cookie<'c> {
 
     fn fmt_parameters(&self, f: &mut fmt::Formatter) -> fmt::Result {
         if let Some(true) = self.http_only() {
-            write!(f, "; HttpOnly")?;
+            f.write_str("; HttpOnly")?;
         }
 
         if let Some(same_site) = self.same_site() {
-            write!(f, "; SameSite={}", same_site)?;
+            f.write_str("; SameSite=")?;
+            f.write_str(&same_site.to_string())?;
 
             if same_site.is_none() && self.secure().is_none() {
-                write!(f, "; Secure")?;
+                f.write_str("; Secure")?;
             }
         }
 
         if let Some(true) = self.secure() {
-            write!(f, "; Secure")?;
+            f.write_str("; Secure")?;
         }
 
         if let Some(path) = self.path() {
-            write!(f, "; Path={}", path)?;
+            f.write_str("; Path=")?;
+            f.write_str(path)?;
         }
 
         if let Some(domain) = self.domain() {
-            write!(f, "; Domain={}", domain)?;
+            f.write_str("; Domain=")?;
+            f.write_str(domain)?;
         }
 
         if let Some(max_age) = self.max_age() {
-            write!(f, "; Max-Age={}", max_age.as_secs())?;
+            f.write_str("; Max-Age=")?;
+            f.write_str(&max_age.as_secs().to_string())?;
         }
 
         Ok(())
@@ -893,7 +898,9 @@ impl<'c> fmt::Display for Cookie<'c> {
     /// assert_eq!(&cookie.to_string(), "foo=bar; Path=/");
     /// ```
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        write!(f, "{}={}", self.name(), self.value())?;
+        f.write_str(self.name())?;
+        f.write_char('=')?;
+        f.write_str(self.value())?;
         self.fmt_parameters(f)
     }
 }
